Struct bee_common::logger::LoggerConfig [−][src]
pub struct LoggerConfig { /* fields omitted */ }Expand description
Logger configuration.
Implementations
Creates a builder for a logger config.
Returns the color flag of the LoggerConfig.
Returns the width of the target section of the LoggerConfig.
Returns the width of the level section of the LoggerConfig.
Returns the outputs of the LoggerConfig.