Module bee_common::time [−][src]
A module that provides common functions for timestamps.
Functions
Produces a formatted String from a timestamp, displayed as local time.
Takes a unix timestamp and returns a formatted String.
Creates a new time from a unix timestamp, at UTC.
Retrieves the current timestamp, at UTC.